<?php

class XSLTransformer
{
	var $_method;
	var $_php_info = '';
	
	function XSLTransformer()
	{
	}
	
	function doXSLTransform($basePath, $xml_str, $xsl_file, $params)
	{
		if (!isset($this->_method) && empty($this->_method)) return false;
		if (!file_exists($basePath.$xsl_file)) return false;

		$content = '';
		$xsl_str = $this->_getFileContent($basePath.$xsl_file); 
		switch ($this->_method)
		{
			case 'SBCore': $content = $this->_doSBCoreTransform($xml_str, $xsl_str, $params); break;
			case 'XMLDom': $content = $this->_doXMLDomTransform($xml_str, $xsl_str, $params); break;
			case 'Sablot': $content = $this->_doSablotTransform($xml_str, $xsl_str, $params); break;
		}
		return $content;
	}
	
	function getAvailableXSLTransformMethod()
	{
		$this->_method = false;
		if ($this->_ableSBCoreTransform()) $this->_method = 'SBCore';
		if ($this->_ableXMLDomTransform()) $this->_method = 'XMLDom';
		if ($this->_ableSablotTransform()) $this->_method = 'Sablot';
		return $this->_method;
	}
	
	function _ableSBCoreTransform()
	{
		if (function_exists('sb_getxslt')) return true;
		return false;
	}

	function _doSBCoreTransform($xml_str, $xsl_str, $params)
	{
	    $xslt = sb_getxslt();
		$result = $xslt->processstr($xml_str, $xsl_str, $params);
        if (!$result)
        {
	        $err=$xslt->error();
			return false;
        }
		return $result;
	}
	
	function _ableXMLDomTransform()
	{
		if (empty($this->_php_info))
		{
			ob_start();
			phpinfo();
			$this->_php_info = ob_get_contents();
			ob_end_clean();
		}
		if (strpos($this->_php_info, '--with-dom-xslt')) return true;
		return false;
	}

	function _doXMLDomTransform($xml_str, $xsl_str, $params)
	{
		$content = '';
		$domxml = @domxml_open_mem($xml_str);
		$domxsl = @domxml_xslt_stylesheet($xsl_str);
		$result =  $domxsl->process($domxml);
		$content = $domxsl->result_dump_mem($result);
		return $content;
	}
	
	function _ableSablotTransform()
	{
		return (extension_loaded('xslt'));
	}

	function _doSablotTransform($xml_str, $xsl_str, $params)
	{     
		$content = '';
		$xh = xslt_create();
		xslt_set_encoding($xh,"UTF-8");
		$content = xslt_process($xh, 'arg:/_xml', 'arg:/_xsl', NULL, array('/_xml' => $xml_str, '/_xsl' => $xsl_str), $params); 
		return $content;
	}
	
	function _getFileContent($fileName)
	{
		$fileContent = "";
		$buf = file($fileName);
		if(is_array($buf) && count($buf)) $fileContent = implode ('', $buf);
		return $fileContent;
	}	
}
?>